import libtcodpy as libtcod
import playerMod
import objMod
import wininiMod

################
#MAP PROPERTIES#
################

SCREEN_WIDTH = 80
SCREEN_HEIGHT = 50
LIMIT_FPS = 20

water_level_5       = libtcod.darkest_azure
water_level_4       = libtcod.darker_azure
water_level_3       = libtcod.dark_azure
water_level_2       = libtcod.azure
water_level_1       = libtcod.light_azure

grass_level_0       = libtcod.Color(105, 139, 34)
sand_level_0        = libtcod.dark_amber
snow_level_0        = libtcod.lightest_grey

forest_level_0      = libtcod.darker_green

blocked_level_0     = libtcod.desaturated_sea

mountain_level_1    = libtcod.Color(139,69,19)
mountain_level_2    = libtcod.Color(205,133,63)
mountain_level_3    = libtcod.Color(238,154,73)
mountain_level_4    = libtcod.Color(255,165,79)
mountain_level_5    = libtcod.Color(210,180,140)

class Tile:
     def __init__(self, level, color, blocked, block_sight = None):
          self.level     = level
          self.color     = color
          self.blocked   = blocked

          if block_sight is None: block_sight = blocked
          self.block_sight = block_sight

class Water_1(Tile):
     def __init__(self):
          Tile.__init__(self,-1,water_level_1, blocked = None)

class Water_2(Tile):
     def __init__(self):
          Tile.__init__(self,-2,water_level_2, blocked = None)

class Water_3(Tile):
     def __init__(self):
          Tile.__init__(self,-3,water_level_3, blocked = None)

class Water_4(Tile):
     def __init__(self):
          Tile.__init__(self,-4,water_level_4, blocked = None)

class Water_5(Tile):
     def __init__(self):
          Tile.__init__(self,-5,water_level_5, blocked = None)
        
class Grass(Tile):
     def __init__(self):
          Tile.__init__(self, 0,grass_level_0, blocked = None)

class Snow(Tile):
     def __init__(self):
          Tile.__init__(self, 0,snow_level_0, blocked = None)

class Sand(Tile):
     def __init__(self):
          Tile.__init__(self, 0,sand_level_0, blocked = None)

class Forest(Tile):
     def __init__(self):
          Tile.__init__(self, 0,forest_level_0, blocked = True)

class BlockedTerrain(Tile):
     def __init__(self):
          Tile.__init__(self, 0, blocked_level_0, blocked = None)

class Mountain_1(Tile):
     def __init__(self):
          Tile.__init__(self, 1,mountain_level_1, blocked = None)

class Mountain_2(Tile):
     def __init__(self):
          Tile.__init__(self, 2,mountain_level_2, blocked = None)

class Mountain_3(Tile):
     def __init__(self):
          Tile.__init__(self, 3, mountain_level_3, blocked = None)

class Mountain_4(Tile):
     def __init__(self):
          Tile.__init__(self, 4, mountain_level_4, blocked = None)

class Mountain_5(Tile):
     def __init__(self):
          Tile.__init__(self, 5, mountain_level_5, blocked = None)


class Map:
     def __init__(self, width, height, tile):
          self.squares = [[tile
                 for y in range(height)]
                     for x in range(width)]
          self.width = width
          self.height = height
          self.objects = [objMod.locust]
          
     def set_tile(self, x, y, tile):
          self.squares[x][y] = tile  

class Renderer:
     def __init__(self, combat_mode_map):
          self.combat_mode_map = combat_mode_map
          

     def render_all(self,combat_mode_map):
          for y in range(self.combat_mode_map.height):
               for x in range(self.combat_mode_map.width):
                    libtcod.console_set_char_background(0, x, y, self.combat_mode_map.squares[x][y].color, libtcod.BKGND_SET)

          for object in self.combat_mode_map.objects:
               object.draw()

def is_block(x,y):
     if mapMod.squares[x][y].blocked:
          return True
     for object in mapMod.objects:
          if object.block and object.x == x and object.y == y:
               return True
     return False

def level_difference(map_test, x, dx, y, dy):
               return (map_test.squares[x][y].level - map_test.squares[x + dx][y - dy].level)
